@@ -1,6 +1,9 @@
 use thiserror::Error;
 
+pub type Result<T> = std::result::Result<T, Error>;
+
 #[derive(Error, Debug, PartialEq)]
+#[non_exhaustive]
 pub enum Error {
     /// Wrong marshal size.
     #[error("Wrong marshal size")]
@@ -85,14 +88,33 @@ pub enum Error {
     /// Packet status chunk is not 2 bytes.
     #[error("Packet status chunk must be 2 bytes")]
     PacketStatusChunkLength,
+    #[error("Invalid bitrate")]
+    InvalidBitrate,
+    #[error("Wrong chunk type")]
+    WrongChunkType,
+    #[error("Struct contains unexpected member type")]
+    BadStructMemberType,
+    #[error("Cannot read into non-pointer")]
+    BadReadParameter,
 
-    #[allow(non_camel_case_types)]
     #[error("{0}")]
-    new(String),
+    Util(#[from] util::Error),
+
+    #[error("{0}")]
+    Other(String),
 }
 
-impl Error {
-    pub fn equal(&self, err: &anyhow::Error) -> bool {
-        err.downcast_ref::<Self>().map_or(false, |e| e == self)
+impl From<Error> for util::Error {
+    fn from(e: Error) -> Self {
+        util::Error::from_std(e)
+    }
+}
+
+impl PartialEq<util::Error> for Error {
+    fn eq(&self, other: &util::Error) -> bool {
+        if let Some(down) = other.downcast_ref::<Error>() {
+            return self == down;
+        }
+        false
     }
 }
