@@ -1,5 +1,7 @@
 use super::*;
 use bytes::Bytes;
+use std::sync::Arc;
+use tokio::sync::Mutex;
 
 #[test]
 fn test_transport_layer_nack_unmarshal() {
@@ -71,12 +73,10 @@ fn test_transport_layer_nack_unmarshal() {
 
         if let Some(err) = want_error {
             let got_err = got.err().unwrap();
-            assert!(
-                err.equal(&got_err),
+            assert_eq!(
+                err, got_err,
                 "Unmarshal {} rr: err = {:?}, want {:?}",
-                name,
-                got_err,
-                err,
+                name, got_err, err,
             );
         } else {
             let actual = got.unwrap();
@@ -124,17 +124,15 @@ fn test_transport_layer_nack_roundtrip() {
 
         if let Some(err) = want_error {
             let got_err = got.err().unwrap();
-            assert!(
-                err.equal(&got_err),
+            assert_eq!(
+                err, got_err,
                 "Unmarshal {} rr: err = {:?}, want {:?}",
-                name,
-                got_err,
-                err,
+                name, got_err, err,
             );
         } else {
             let mut data = got.ok().unwrap();
             let actual = TransportLayerNack::unmarshal(&mut data)
-                .expect(format!("Unmarshal {}", name).as_str());
+                .unwrap_or_else(|_| panic!("Unmarshal {}", name));
 
             assert_eq!(
                 actual, want,
@@ -194,6 +192,52 @@ fn test_nack_pair() {
     );
 }
 
+#[tokio::test]
+async fn test_nack_pair_range() {
+    let n = NackPair {
+        packet_id: 42,
+        lost_packets: 2,
+    };
+
+    let out = Arc::new(Mutex::new(vec![]));
+    let out1 = Arc::clone(&out);
+    n.range(Box::new(
+        move |s: u16| -> Pin<Box<dyn Future<Output = bool> + Send + 'static>> {
+            let out2 = Arc::clone(&out1);
+            Box::pin(async move {
+                let mut o = out2.lock().await;
+                o.push(s);
+                true
+            })
+        },
+    ))
+    .await;
+
+    {
+        let o = out.lock().await;
+        assert_eq!(*o, &[42, 44]);
+    }
+
+    let out = Arc::new(Mutex::new(vec![]));
+    let out1 = Arc::clone(&out);
+    n.range(Box::new(
+        move |s: u16| -> Pin<Box<dyn Future<Output = bool> + Send + 'static>> {
+            let out2 = Arc::clone(&out1);
+            Box::pin(async move {
+                let mut o = out2.lock().await;
+                o.push(s);
+                false
+            })
+        },
+    ))
+    .await;
+
+    {
+        let o = out.lock().await;
+        assert_eq!(*o, &[42]);
+    }
+}
+
 #[test]
 fn test_transport_layer_nack_pair_generation() {
     let test = vec![
